#include <LiquidCrystal.h>
#include <SoftwareSerial.h>

// Define pins for LCD
const int rs = 12;
const int en = 11;
const int d4 = 9;
const int d5 = 8;
const int d6 = 7;
const int d7 = 6;

// Define pins for PIR sensor and speaker
const int pirPin = 2;
const int speakerPin = 10;
const int potPin = A0;

// Define pins for GSM module (using SoftwareSerial)
const int gsmRxPin = 4; // Connect to TX of SIM800L
const int gsmTxPin = 3; // Connect to RX of SIM800L

// Variables
int previousPirState = LOW;
int volume = 0;
int motionCount = 0;

// LCD object
LiquidCrystal lcd(rs, en, d4, d5, d6, d7);

// GSM object
SoftwareSerial sim800l(gsmRxPin, gsmTxPin);

void setup() {
  // Initialize LCD
  lcd.begin(16, 2);
  lcd.setCursor(0, 0);
  lcd.print("Sistem pornit");

  // Configure pins for PIR sensor and speaker
  pinMode(pirPin, INPUT);
  pinMode(speakerPin, OUTPUT);

  // Initialize GSM module
  sim800l.begin(9600);

  // Send initial SMS
  sendSMS("Sistem pornit");

  delay(2000); // Delay to allow user to see the initial message
  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("Sistem de");
  lcd.setCursor(0, 1);
  lcd.print("Securitate");
}

void loop() {
  // Read current state of the PIR sensor
  int pirState = digitalRead(pirPin);

  if (pirState == HIGH && previousPirState == LOW) {
    motionCount++; // Increment motion count

    // Ensure no tone is playing before updating LCD
    noTone(speakerPin);

    // Display message on LCD
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Miscare detectata");

    delay(300); // Delay to ensure LCD update is complete

    if (motionCount > 10) {
      // Simulate natural disaster warning sound
      for (int i = 0; i < 3; i++) {
        tone(speakerPin, 1000); // High frequency
        delay(250);
        tone(speakerPin, 500); // Low frequency
        delay(250);
      }
      noTone(speakerPin); // Stop tone
      sendSMS("Alerta! Miscare suspecta.");
      motionCount = 0; // Reset motion count after siren sound
    } else {
      // Determine the frequency based on motion count
      int frequency = (motionCount > 5) ? 2000 : 1000; // Change frequency after 5 detections

      // Generate sound three times
      for (int i = 0; i < 3; i++) {
        volume = analogRead(potPin) / 4;
        tone(speakerPin, frequency, 500); // Sound duration 500ms
        delay(1000); // Delay 1 second between sounds
      }
    }

    delay(2000); // Keep the "Miscare detectata" message for 2 seconds
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Sistem de");
    lcd.setCursor(0, 1);
    lcd.print("Securitate");
  }

  // Update previous PIR state
  previousPirState = pirState;
}

void sendSMS(String message) {
  sim800l.println("AT+CMGF=1"); // Set SMS mode to text
  delay(100);
  sim800l.println("AT+CMGS=\"+40711000116\""); // Replace with your phone number
  delay(100);
  sim800l.println(message);
  delay(100);
  sim800l.println((char)26); // ASCII code of CTRL+Z
  delay(100);
}
